Used to implement and expose the tools to implement canonization of Key Expressions for string-like types. The average user doesn’t need to bother with it.
Traits
- Canonize
- Helper trait implemented for types that can be canonized in place
by
KeyExpr::autocanonize().